=======================
demo energy consumption
=======================


.. image:: https://img.shields.io/pypi/v/demo_energy_consumption.svg
        :target: https://pypi.python.org/pypi/demo_energy_consumption

.. image:: https://img.shields.io/travis/denismolin/demo_energy_consumption.svg
        :target: https://travis-ci.com/denismolin/demo_energy_consumption

.. image:: https://readthedocs.org/projects/demo-energy-consumption/badge/?version=latest
        :target: https://demo-energy-consumption.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




demo energy consumption shows how to seamlessly leverage Teradata Vantage in your Python projects.


* Free software: MIT license
* Documentation: https://demo-energy-consumption.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
